==> kannel_1.4.4.orig.tar.gz: gateway-1.4.4/gw/meta_data.h <==
/* ====================================================================
 * The Kannel Software License, Version 1.0
 *
 * Copyright (c) 2001-2014 Kannel Group
 * Copyright (c) 1998-2001 WapIT Ltd.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Kannel Group (http://www.kannel.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Kannel" and "Kannel Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please
 *    contact org@kannel.org.
 *
 * 5. Products derived from this software may not be called "Kannel",
 *    nor may "Kannel" appear in their name, without prior written
 *    permission of the Kannel Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE KANNEL GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Kannel Group.  For more information on
 * the Kannel Group, please see <http://www.kannel.org/>.
 *
 * Portions of this software are based upon software originally written at
 * WapIT Ltd., Helsinki, Finland for the Kannel project.
 */

/*
 * meta_data.h
 *
 * Meta Data manupilation.
 * 
 * Alexander Malysh <amalysh kannel.org>, 2007-2009
 */

#ifndef META_DATA_H
#define META_DATA_H

#define METADATA_DLR_GROUP            "dlr"
#define METADATA_DLR_GROUP_DONETIME   "donetime"
#define METADATA_DLR_GROUP_SUBMITTIME "submittime"
#define METADATA_DLR_GROUP_ERRORCODE  "errorcode"

/**
 * Get Dictionary with all values for this group.
 */
Dict *meta_data_get_values(const Octstr *data, const char *group);
/**
 * Replace Dictionary for the given group.
 */
int meta_data_set_values(Octstr *data, const Dict *dict, const char *group, int replace);
/**
 * Set or replace value for a given group and key.
 */
int meta_data_set_value(Octstr *data, const char *group, const Octstr *key, const Octstr *value, int replace);
/**
 * Get value for a given group and key.
 */
Octstr *meta_data_get_value(Octstr *data, const char *group, const Octstr *key);
/**
 * Merge two meta data strings into one
 */
Octstr *meta_data_merge(const Octstr *data, const Octstr *new_data, int replace);


#endif

==> kannel_1.4.5.orig.tar.gz: gateway-1.4.5/gw/meta_data.h <==
/* ====================================================================
 * The Kannel Software License, Version 1.0
 *
 * Copyright (c) 2001-2018 Kannel Group
 * Copyright (c) 1998-2001 WapIT Ltd.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Kannel Group (http://www.kannel.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Kannel" and "Kannel Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please
 *    contact org@kannel.org.
 *
 * 5. Products derived from this software may not be called "Kannel",
 *    nor may "Kannel" appear in their name, without prior written
 *    permission of the Kannel Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE KANNEL GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Kannel Group.  For more information on
 * the Kannel Group, please see <http://www.kannel.org/>.
 *
 * Portions of this software are based upon software originally written at
 * WapIT Ltd., Helsinki, Finland for the Kannel project.
 */

/*
 * meta_data.h
 *
 * Meta Data manupilation.
 * 
 * Alexander Malysh <amalysh kannel.org>, 2007-2009
 */

#ifndef META_DATA_H
#define META_DATA_H

#define METADATA_DLR_GROUP					"dlr"
#define METADATA_DLR_GROUP_DONETIME   		"donetime"
#define METADATA_DLR_GROUP_SUBMITTIME 		"submittime"
#define METADATA_DLR_GROUP_ERRORCODE  		"errorcode"

#define METADATA_ORIG_MSG_GROUP       		"orig_msg"
#define METADATA_ORIG_MSG_GROUP_DLR_MASK 	"dlr_mask"

#define METADATA_SMPP_GROUP           		"smpp"

/**
 * Get Dictionary with all values for this group.
 */
Dict *meta_data_get_values(const Octstr *data, const char *group);
/**
 * Replace Dictionary for the given group.
 */
int meta_data_set_values(Octstr *data, const Dict *dict, const char *group, int replace);
/**
 * Set or replace value for a given group and key.
 */
int meta_data_set_value(Octstr *data, const char *group, const Octstr *key, const Octstr *value, int replace);
/**
 * Get value for a given group and key.
 */
Octstr *meta_data_get_value(Octstr *data, const char *group, const Octstr *key);
/**
 * Merge two meta data strings into one
 */
Octstr *meta_data_merge(const Octstr *data, const Octstr *new_data, int replace);


#endif
